.. _sec_installation:

############
Installation
############

``ldgm`` comprises both a Python package (to create LDGMs) and a set of Matlab functions (to infer LDGM precision matrices and perform matrix algebra operations with them).

To install the ``ldgm`` Python package simply run::

    $ python3 -m pip install git+https://github.com/awohns/ldgm.git

To use the Matlab code, first clone the repo::

    $ git clone --depth 1 https://github.com/awohns/ldgm.git

And then run Matlab scripts in the ``matlab/`` directory.

